==> pogamut-emohawk-ville-3.5.2-20130819.040212-108-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/ingredient/meat/AbstractMeatBitMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.meat;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.AbstractSolidIngredientSliceMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.IFriableIngredientMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.ingredient.meat.AbstractMeatBitReplication;

/** Meat bit memorization
 * 
 * @author Paletz
 */
public class AbstractMeatBitMemorization
	<MemorizedClass extends AbstractMeatBitReplication>
	extends AbstractSolidIngredientSliceMemorization<MemorizedClass>
	implements IFriableIngredientMemorization<MemorizedClass> {

	protected float topFriedness, bottomFriedness;
	protected boolean isUpsideDown;
	
	public AbstractMeatBitMemorization( 
		MemorizedClass object,
		ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory, deferredConstructorChainer );
		topFriedness = object.getTopFriedness();
		bottomFriedness = object.getBottomFriedness();
		isUpsideDown = object.getIsUpsideDown();
	}	
	
	@Override
	public float getTopFriedness() {
		return topFriedness;
	}
	
	@Override
	public float getBottomFriedness() {
		return bottomFriedness;
	}
	
	@Override
	public boolean getIsUpsideDown() {
		return isUpsideDown;
	}
}

==> pogamut-emohawk-ville-3.5.4-20140114.043709-29-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/item/ingredient/meat/AbstractMeatBitMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.meat;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.AbstractSolidIngredientSliceMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.ingredient.IFriableIngredientMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.item.ingredient.meat.AbstractMeatBitReplica;

/** Meat bit memorization
 * 
 * @author Paletz
 */
public class AbstractMeatBitMemorization
	<MemorizedClass extends AbstractMeatBitReplica>
	extends AbstractSolidIngredientSliceMemorization<MemorizedClass>
	implements IFriableIngredientMemorization<MemorizedClass> {

	protected float topFriedness, bottomFriedness;
	protected boolean isUpsideDown;
	
	public AbstractMeatBitMemorization( 
		MemorizedClass object,
		ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory, deferredConstructorChainer );
		topFriedness = object.getTopFriedness();
		bottomFriedness = object.getBottomFriedness();
		isUpsideDown = object.getIsUpsideDown();
	}	
	
	@Override
	public float getTopFriedness() {
		return topFriedness;
	}
	
	@Override
	public float getBottomFriedness() {
		return bottomFriedness;
	}
	
	@Override
	public boolean getIsUpsideDown() {
		return isUpsideDown;
	}
}
